@@ -275,7 +275,31 @@ if (requireNamespace("timeDate", quietly = TRUE)) {
     expect_equal(is.bizday('2016-07-12', 'Rmetrics/LONDON'),
                  as.logical(timeDate::isBizday(timeDate::timeDate('2016-01-12'), timeDate::holidayLONDON(2016)))
     )
+    
+    expect_equal(is.bizday('2016-12-31', 'Rmetrics/LONDON'),
+                 as.logical(timeDate::isBizday(timeDate::timeDate('2016-12-31'), timeDate::holidayLONDON(2016)))
+    )
+    
+    load_rmetrics_calendars(2017)
+    expect_equal(is.bizday('2017-01-01', 'Rmetrics/LONDON'),
+                 as.logical(timeDate::isBizday(timeDate::timeDate('2017-01-01'), timeDate::holidayLONDON(2017)))
+    )
+    
+    expect_equal(is.bizday('2017-12-31', 'Rmetrics/LONDON'),
+                 as.logical(timeDate::isBizday(timeDate::timeDate('2017-12-31'), timeDate::holidayLONDON(2017)))
+    )
   })
   
 }
 
+context("bizdiff")
+
+test_that("it should compute bizdays between dates in a vector", {
+  dates <- c("2017-05-10", "2017-05-12", "2017-05-17")
+  expect_equal(bizdiff(dates, "Brazil/ANBIMA"), c(2, 3))
+})
+
+test_that("it should return an empty vector for a single element vector", {
+  expect_equal(bizdiff("2017-01-02", "Brazil/ANBIMA"), numeric())
+})
+
